.. module:: examples

.. _tutorials:

=====================
Tutorials & Topics
=====================


Tutorials
==============

Most of the material presented in the these tutorials is based on the
:mod:`examples` module in the `pulsar distribution <https://github.com/quantmind/pulsar>`_.

.. toctree::
   :maxdepth: 1

   hello
   clients
   wsgi
   deploy
   httpbin
   proxy
   calculator
   chat
   taskqueue
   django
   tweets
   philosophers
   pulsards
   udp
   webmail


Topics
==============

These sections cover **pulsar internals** for the curious reader.

.. toctree::
   :maxdepth: 1

   actors
   coroutine
   messages
   events
   signal
   sync
   benchmarking
   cextensions


